<?php

namespace App\Tests\Controller;

use App\Entity\Intern;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\EntityRepository;
use Symfony\Bundle\FrameworkBundle\KernelBrowser;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;

final class InternControllerTest extends WebTestCase
{
    private KernelBrowser $client;
    private EntityManagerInterface $manager;
    private EntityRepository $repository;
    private string $path = '/intern/';

    protected function setUp(): void
    {
        $this->client = static::createClient();
        $this->manager = static::getContainer()->get('doctrine')->getManager();
        $this->repository = $this->manager->getRepository(Intern::class);

        foreach ($this->repository->findAll() as $object) {
            $this->manager->remove($object);
        }

        $this->manager->flush();
    }

    public function testIndex(): void
    {
        $this->client->followRedirects();
        $crawler = $this->client->request('GET', $this->path);

        self::assertResponseStatusCodeSame(200);
        self::assertPageTitleContains('Intern index');

        // Use the $crawler to perform additional assertions e.g.
        // self::assertSame('Some text on the page', $crawler->filter('.p')->first());
    }

    public function testNew(): void
    {
        $this->markTestIncomplete();
        $this->client->request('GET', sprintf('%snew', $this->path));

        self::assertResponseStatusCodeSame(200);

        $this->client->submitForm('Save', [
            'intern[nickname]' => 'Testing',
            'intern[roles]' => 'Testing',
            'intern[password]' => 'Testing',
            'intern[firstName]' => 'Testing',
            'intern[lastName]' => 'Testing',
            'intern[tel]' => 'Testing',
            'intern[address]' => 'Testing',
            'intern[mail]' => 'Testing',
            'intern[coverLetter]' => 'Testing',
            'intern[resume]' => 'Testing',
        ]);

        self::assertResponseRedirects($this->path);

        self::assertSame(1, $this->repository->count([]));
    }

    public function testShow(): void
    {
        $this->markTestIncomplete();
        $fixture = new Intern();
        $fixture->setNickname('My Title');
        $fixture->setRoles('My Title');
        $fixture->setPassword('My Title');
        $fixture->setFirstName('My Title');
        $fixture->setLastName('My Title');
        $fixture->setTel('My Title');
        $fixture->setAddress('My Title');
        $fixture->setMail('My Title');
        $fixture->setCoverLetter('My Title');
        $fixture->setResume('My Title');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s', $this->path, $fixture->getId()));

        self::assertResponseStatusCodeSame(200);
        self::assertPageTitleContains('Intern');

        // Use assertions to check that the properties are properly displayed.
    }

    public function testEdit(): void
    {
        $this->markTestIncomplete();
        $fixture = new Intern();
        $fixture->setNickname('Value');
        $fixture->setRoles('Value');
        $fixture->setPassword('Value');
        $fixture->setFirstName('Value');
        $fixture->setLastName('Value');
        $fixture->setTel('Value');
        $fixture->setAddress('Value');
        $fixture->setMail('Value');
        $fixture->setCoverLetter('Value');
        $fixture->setResume('Value');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s/edit', $this->path, $fixture->getId()));

        $this->client->submitForm('Update', [
            'intern[nickname]' => 'Something New',
            'intern[roles]' => 'Something New',
            'intern[password]' => 'Something New',
            'intern[firstName]' => 'Something New',
            'intern[lastName]' => 'Something New',
            'intern[tel]' => 'Something New',
            'intern[address]' => 'Something New',
            'intern[mail]' => 'Something New',
            'intern[coverLetter]' => 'Something New',
            'intern[resume]' => 'Something New',
        ]);

        self::assertResponseRedirects('/intern/');

        $fixture = $this->repository->findAll();

        self::assertSame('Something New', $fixture[0]->getNickname());
        self::assertSame('Something New', $fixture[0]->getRoles());
        self::assertSame('Something New', $fixture[0]->getPassword());
        self::assertSame('Something New', $fixture[0]->getFirstName());
        self::assertSame('Something New', $fixture[0]->getLastName());
        self::assertSame('Something New', $fixture[0]->getTel());
        self::assertSame('Something New', $fixture[0]->getAddress());
        self::assertSame('Something New', $fixture[0]->getMail());
        self::assertSame('Something New', $fixture[0]->getCoverLetter());
        self::assertSame('Something New', $fixture[0]->getResume());
    }

    public function testRemove(): void
    {
        $this->markTestIncomplete();
        $fixture = new Intern();
        $fixture->setNickname('Value');
        $fixture->setRoles('Value');
        $fixture->setPassword('Value');
        $fixture->setFirstName('Value');
        $fixture->setLastName('Value');
        $fixture->setTel('Value');
        $fixture->setAddress('Value');
        $fixture->setMail('Value');
        $fixture->setCoverLetter('Value');
        $fixture->setResume('Value');

        $this->manager->persist($fixture);
        $this->manager->flush();

        $this->client->request('GET', sprintf('%s%s', $this->path, $fixture->getId()));
        $this->client->submitForm('Delete');

        self::assertResponseRedirects('/intern/');
        self::assertSame(0, $this->repository->count([]));
    }
}
